Module blaxel.core.client.models.metric
=======================================

Classes
-------

`Metric(rate: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, request_total: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, timestamp: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Metric
    
    Attributes:
        rate (Union[Unset, int]): Metric value
        request_total (Union[Unset, int]): Metric value
        timestamp (Union[Unset, str]): Metric timestamp
    
    Method generated by attrs for class Metric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `rate: blaxel.core.client.types.Unset | int`
    :

    `request_total: blaxel.core.client.types.Unset | int`
    :

    `timestamp: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :